@@ -1,14 +1,14 @@
 /*
   This file is part of KAddressBook.
 
-  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #pragma once
 
-#include <KParts/Event>
+#include <KParts/GUIActivateEvent>
 #include <KParts/Part>
 #include <kparts/readonlypart.h>
 
